from .utils import (
    Result,
    get_fld,
    get_tld,
    get_tld_names,
    is_tld,
    parse_tld,
    reset_tld_names,
    update_tld_names,
)

__title__ = "tld"
__version__ = "0.13.2"
__author__ = "Artur Barseghyan"
__copyright__ = "2013-2026 Artur Barseghyan"
__license__ = "MPL-1.1 OR GPL-2.0-only OR LGPL-2.1-or-later"
__all__ = (
    "Result",
    "get_fld",
    "get_tld",
    "get_tld_names",
    "is_tld",
    "parse_tld",
    "reset_tld_names",
    "update_tld_names",
)
